# Changelog

## [0.2.0](https://github.com/LEB-EPFL/just-focus/compare/v0.1.0...v0.2.0) (2025-08-05)


### Features

* Add argument to set phase mask center ([#5](https://github.com/LEB-EPFL/just-focus/issues/5)) ([b4ffd5f](https://github.com/LEB-EPFL/just-focus/commit/b4ffd5f5357f20320bce94e58376839a16fcfcc4))

## 0.1.0 (2025-08-04)


### Features

* Add halfmoon focal field script ([7849ae8](https://github.com/LEB-EPFL/just-focus/commit/7849ae8840a4fcce774b789d9030481b2cdae9a9))
* Add linear phase correction and aperture softening ([#2](https://github.com/LEB-EPFL/just-focus/issues/2)) ([4f37e7b](https://github.com/LEB-EPFL/just-focus/commit/4f37e7b3c453b63226be3c32d765ba9e81d46ab6))
* Initial commit ([49390d8](https://github.com/LEB-EPFL/just-focus/commit/49390d810dc5e384826cd62fb4a448ac91c90686))


### Documentation

* Add quickstart to README ([4e624c9](https://github.com/LEB-EPFL/just-focus/commit/4e624c9a7d7afcaea1712b8f209b30d6d367b9c9))
* Add related packages section ([832a94e](https://github.com/LEB-EPFL/just-focus/commit/832a94e1123867406c65a0038dab4ba5fff9b103))
* Add resources to README ([83f2218](https://github.com/LEB-EPFL/just-focus/commit/83f2218b23c19e257134321f8c77f0db688bc05c))
